==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebActivePaneEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebActivePaneEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebActivePaneEventArgsDescription, _super);
    function WebActivePaneEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebActivePaneEventArgsDescription.prototype.get_type = function () {
        return "WebActivePaneEventArgs";
    };
    Object.defineProperty(WebActivePaneEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebActivePaneEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Detail");
        },
        enumerable: true,
        configurable: true
    });
    WebActivePaneEventArgsDescription.$t = markType(WebActivePaneEventArgsDescription, 'WebActivePaneEventArgsDescription', Description.$);
    return WebActivePaneEventArgsDescription;
}(Description));
export { WebActivePaneEventArgsDescription };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebActivePaneEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebActivePaneEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebActivePaneEventArgsDescription, _super);
    function WebActivePaneEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.g = null;
        return _this;
    }
    WebActivePaneEventArgsDescription.prototype.get_type = function () {
        return "WebActivePaneEventArgs";
    };
    Object.defineProperty(WebActivePaneEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebActivePaneEventArgsDescription.prototype, "newPane", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("NewPane");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebActivePaneEventArgsDescription.prototype, "oldPane", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("OldPane");
        },
        enumerable: true,
        configurable: true
    });
    WebActivePaneEventArgsDescription.$t = markType(WebActivePaneEventArgsDescription, 'WebActivePaneEventArgsDescription', Description.$);
    return WebActivePaneEventArgsDescription;
}(Description));
export { WebActivePaneEventArgsDescription };
